pub fn kill_node(handle: &RedisServerHandle)Expand description
Kill a node immediately with SIGKILL.
The process is terminated without any chance to clean up. This simulates a hard crash (e.g., OOM kill, hardware failure).
pub fn kill_node(handle: &RedisServerHandle)Kill a node immediately with SIGKILL.
The process is terminated without any chance to clean up. This simulates a hard crash (e.g., OOM kill, hardware failure).