pub async fn trigger_failover(replica: &RedisServerHandle) -> Result<String>Expand description
Trigger a CLUSTER FAILOVER on a replica node.
If the initial failover fails because the master is down, retries with
CLUSTER FAILOVER FORCE.
pub async fn trigger_failover(replica: &RedisServerHandle) -> Result<String>Trigger a CLUSTER FAILOVER on a replica node.
If the initial failover fails because the master is down, retries with
CLUSTER FAILOVER FORCE.