read_pidfile

Function read_pidfile 

pub fn read_pidfile(path: &Path) -> Option<u32>
Read a PID from a pidfile.

Returns None if the file does not exist, cannot be read, or its contents cannot be parsed as a u32.